@@ -9,7 +9,6 @@ from __future__ import absolute_import, print_function
 import ast
 import codecs
 import dis
-import imp
 import marshal
 import os
 import re
@@ -23,6 +22,7 @@ import pkg_resources
 from altgraph import GraphError
 from altgraph.ObjectGraph import ObjectGraph
 
+from . import _imp as imp
 from . import util, zipio
 
 if sys.version_info[0] == 2:
@@ -269,12 +269,20 @@ def find_module(name, path=None):
         if ExtensionFileLoader is not None and isinstance(loader, ExtensionFileLoader):
             filename = loader.path
 
-            for _sfx, _mode, _type in imp.get_suffixes():
-                if _type == imp.C_EXTENSION and filename.endswith(_sfx):
-                    description = (_sfx, "rb", imp.C_EXTENSION)
-                    break
+            if imp is not None:
+                for _sfx, _mode, _type in imp.get_suffixes():
+                    if _type == imp.C_EXTENSION and filename.endswith(_sfx):
+                        description = (_sfx, "rb", imp.C_EXTENSION)
+                        break
+                else:
+                    raise RuntimeError("Don't know how to handle %r" % (importer,))
             else:
-                raise RuntimeError("Don't know how to handle %r" % (importer,))
+                for sfx in importlib.machinery.EXTENSION_SUFFIXES:
+                    if filename.endswith(sfx):
+                        description = (_sfx, "rb", imp.C_EXTENSION)
+                        break
+                else:
+                    raise RuntimeError("Don't know how to handle %r" % (importer,))
 
             return (None, filename, description)
 
